@@ -63,7 +63,7 @@ gpa_transport_selector_get_type (void)
 			NULL, NULL,
 			sizeof (GPATransportSelector),
 			0,
-			(GInstanceInitFunc) gpa_transport_selector_init,
+			(GInstanceInitFunc) gpa_transport_selector_init
 		};
 		type = g_type_register_static (GPA_TYPE_WIDGET, "GPATransportSelector", &info, 0);
 	}
@@ -504,8 +504,11 @@ gpa_transport_selector_check_consistency_real (GPATransportSelector *ts)
 	if (backend == NULL)
 		return TRUE;
 
-	if (strcmp (backend, "file") != 0)
+	if (strcmp (backend, "file") != 0) {
+		g_free (backend);
 		return TRUE;
+	}
+	g_free (backend);
 	
 	if (ts->file_name_force)
 		return TRUE;
